from typing import Any, Union
import pandas as pd
from pymongo.mongo_client import MongoClient
import json
from ensure import ensure_annotations
import json 

class mongo_operation:

    def __init__(self, client_url: str, database_name: str, collection_name: str):
        self.client_url = client_url
        self.database_name = database_name
        self.collection_name = collection_name

    def create_client(self):
        client = MongoClient(self.client_url)
        return client

    def create_database(self):
        client = self.create_client()
        database = client[self.database_name]
        return database
        
    def create_collection(self,collection:str):
        database = self.create_database()
        collection = database[collection]
        return collection

    def insert_record(self,record:Union[dict,list],collection_name:str) -> Any: 
        if type(record) == list:
            for data in record:
                if type(data) != dict:
                    raise TypeError("record must be in the dict")
            collection = self.create_collection(collection_name)
            collection.insert_many(record)
        elif type(record) == dict:
            collection = self.create_collection(collection_name)
            collection.insert_one(record)

    def bulk_insert(self,datafile:str,collection_name:str):
        self.path = datafile

        if self.path.endswith('.csv'):
            data = pd.read_csv(self.path,encoding='utf-8')

        elif self.path.endswith('.xlsx'):
            data = pd.read_excel(self.path,encoding='utf-8')
            
        datajson = json.loads(data.to_json(orient='record'))
        collection = self.create_collection(collection_name)
        collection.insert_many(datajson)



from setuptools import setup, find_packages
from typing import List

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()     
    
__version__ = "0.0.4"
REPO_NAME = "python_package"
PKG_NAME= "anydbconnect"
AUTHOR_USER_NAME = "Shambhuraj11"
AUTHOR_EMAIL = "shambhurajpatil11@gmail.com"

HYPEN_E_DOT = "-e ."

def get_requirement(file_path:str) -> List[str]:
    requirements = []
    with open(file_path) as f:
        requirements = f.readlines()
        requirements = [req.replace("\n","") for req in requirements]

        if HYPEN_E_DOT in requirements:
            requirements.remove(HYPEN_E_DOT)
    
    return requirements

setup(
    name=PKG_NAME,
    version=__version__,
    author=AUTHOR_USER_NAME,
    author_email=AUTHOR_EMAIL,
    description="A python package for connecting with database.",
    long_description=long_description,
    long_description_content="text/markdown",
    url=f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}",
    project_urls={
        "Bug Tracker": f"https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues",
    },
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    install_requires = ["pymongo","pymongo[srv]","dnspython","pandas","numpy","ensure","pytest"]
    )
